@@ -22,7 +22,7 @@ from .select import add_prefix_repo, get_profile, list_profiles, list_repos, set
 
 def init(args):
     """Initializes a prefix"""
-    add_prefix(args.prefix, args.arch)
+    add_prefix(args.prefix, args.arch, args.directory)
 
     if env.INTERACTIVE:
         # If prefix previously existed and the configuration was preserved from when it
@@ -55,14 +55,19 @@ def init(args):
             selected = [0]
         else:
             selected = prompt_num_multi(l10n("init-repositories-prompt"), len(repos))
-        for x in selected:
-            info(f"portmod {args.prefix} select repo add {repos[x].name}")
-            add_prefix_repo(repos[x].name)
-            add_repo(repos[x])
+
+        for index in selected:
+            info(f"portmod {args.prefix} select repo add {repos[index].name}")
+            add_prefix_repo(repos[index].name)
+            add_repo(repos[index])
 
         # Re-initialize prefix with the new repositories
         env.set_prefix(args.prefix)
 
+        if selected:
+            info("portmod sync " + " ".join([repos[x].name for x in selected]))
+            sync([get_repo(repos[x].name) for x in selected])
+
         print()
         profiles = list_profiles(args.arch)
         index = prompt_num(l10n("init-profile-prompt"), len(profiles))
@@ -92,8 +97,17 @@ def add_init_parser(subparsers, parents):
             if not env.REPOS:
                 env.REPOS = [meta_repo]
         parser.add_argument(
-            "arch", help=l10n("init-arch-help"), choices=get_archs(meta_repo.location)
+            "arch",
+            help=l10n("init-arch-help"),
+            choices={arch for repo in env.REPOS for arch in get_archs(repo.location)},
         )
     except Exception:
         parser.add_argument("arch", help=l10n("init-arch-help"))
+
+    parser.add_argument(
+        "directory",
+        metavar=l10n("directory-placeholder"),
+        help=l10n("init-directory-help"),
+        nargs="?",
+    )
     parser.set_defaults(func=init)
