@@ -278,7 +278,7 @@ def scan_commit(commit, err):
     _git = git.Git()
 
     files = _git.show(commit, name_only=True, oneline=True).splitlines()[1:]
-    message = _git.log("HEAD", format="%B", n=1)
+    message = _git.log(commit, format="%B", n=1)
     header_line = message.splitlines()[0]
     packages_modified = [file for file in files if file.endswith(".pybuild")]
     if len(packages_modified) == 1:
@@ -302,6 +302,13 @@ def commit_message(args, repo_root: str, err: Callable[[str], None]):
 
     pybuild_diffs = [diff for diff in changes if diff.b_path.endswith(".pybuild")]
 
+    def check_initial_message(message, initial_message):
+        return (
+            initial_message
+            and initial_message.strip() != message
+            and not initial_message.startswith("fixup!")
+        )
+
     if len(pybuild_diffs) == 1:
         diff = pybuild_diffs[0]
 
@@ -313,21 +320,23 @@ def commit_message(args, repo_root: str, err: Callable[[str], None]):
 
             if diff.deleted_file:
                 message = f"{old.CPN}: Removed version {old.PV}"
-                if initial_message:
+                if check_initial_message(message, initial_message):
                     message += f"\n\n{initial_message}"
             elif diff.new_file:
                 message = f"{new.CPN}: Added version {new.PV}"
-                if initial_message:
+                if check_initial_message(message, initial_message):
                     message += f"\n\n{initial_message}"
             elif diff.renamed_file and old.PV != new.PV:
                 message = f"{new.CPN}: Updated to version {new.PV}"
-                if initial_message:
+                if check_initial_message(message, initial_message):
                     message += f"\n\n{initial_message}"
             else:
                 # Either a change to the package without bump, or just a revision bump.
                 # We can't autogenerate a meaningful message
                 if initial_message:
-                    if initial_message.startswith(new.CPN + ":"):
+                    if initial_message.startswith(
+                        new.CPN + ":"
+                    ) or initial_message.startswith("fixup!"):
                         message = initial_message
                     else:
                         message = f"{new.CPN}: {initial_message}"
