@@ -22,6 +22,7 @@ from portmod.repo.metadata import get_package_metadata
 from portmodlib.atom import Atom
 from portmodlib.colour import blue, bright, green, red
 from portmodlib.l10n import l10n
+from portmodlib.vfs import find_file, list_dir
 
 from . import atom_metavar
 
@@ -339,4 +340,33 @@ def add_query_parser(subparsers, parents):
             print(" " + l10n("query-depgraph-max-depth") + f"({max_depth})")
             print()
 
+    @subcommand(
+        argument("name", type=str, help=l10n("query-vfsfind-help")),
+        parent=subparsers,
+    )
+    def vfsfind(args):
+        """Display the full path of the given file/directory in the VFS"""
+        try:
+            print(find_file(args.name))
+        except FileNotFoundError:
+            error(l10n("file-or-directory-not-found-in-vfs", name=args.name))
+
+    @subcommand(
+        argument(
+            "directory_path", type=str, help=l10n("query-vfslist-help"), nargs="?"
+        ),
+        parent=subparsers,
+    )
+    def vfslist(args):
+        """Display the contents of the given directory in the VFS"""
+        try:
+            if not args.directory_path:
+                for file in list_dir("."):
+                    print(file)
+            else:
+                for file in list_dir(args.directory_path):
+                    print(file)
+        except NotADirectoryError:
+            error(l10n("not-a-directory", directory_path=args.directory_path))
+
     parser.set_defaults(func=lambda args: parser.print_help())
