@@ -19,7 +19,7 @@ from portmod.prompt import display_num_list
 from portmod.repo import RemoteRepo, has_repo
 from portmod.repo.metadata import get_profiles
 from portmod.repo.profiles import get_profile_path
-from portmod.repos import add_repo, get_repos, parse_remote_repos
+from portmod.repos import add_repo, get_remote_repos, get_repos
 from portmod.sync import sync
 from portmodlib.colour import bright, green, lblue
 from portmodlib.l10n import l10n
@@ -49,7 +49,7 @@ def list_profiles(arch: str) -> List[str]:
         profile_path: Optional[str] = get_profile_path()
     except FileNotFoundError:
         profile_path = None
-    for repo, profiles in get_profiles(arch).items():
+    for repo, profiles in get_profiles(arch, env.prefix().REPOS).items():
         print(bright(green(l10n("profile-available", repo=repo))))
         display_num_list(
             [profile for _, profile, _ in profiles],
@@ -63,34 +63,24 @@ def list_profiles(arch: str) -> List[str]:
         )
         start += len(profiles)
     return [
-        profile for values in get_profiles(arch).values() for _, profile, _ in values
+        profile
+        for values in get_profiles(arch, env.prefix().REPOS).values()
+        for _, profile, _ in values
     ]
 
 
-def get_repos_list(arch: Optional[str] = None) -> List[RemoteRepo]:
-    repos = []
-    for repo in env.REPOS:
-        conf = os.path.join(repo.location, "metadata", "repos.cfg")
-        if os.path.exists(conf):
-            repos.extend(
-                [
-                    repo
-                    for repo in parse_remote_repos(conf)
-                    if arch is None or arch in repo.arch
-                ]
-            )
-    return repos
-
-
 def list_repos(arch: str) -> List[RemoteRepo]:
-    repos = get_repos_list(arch)
+    repos = get_remote_repos(arch).values()
     print(bright(green(l10n("repos-available"))))
     display_num_list(
         [bright(repo.name) + ": " + repo.description for repo in repos],
-        [repo.quality + " " + lblue(repo.sync_uri) for repo in repos],
+        [
+            repo.quality + (" " + lblue(repo.sync_uri) if repo.sync_uri else "")
+            for repo in repos
+        ],
         {index for index, repo in enumerate(repos) if has_repo(repo.name)},
     )
-    return repos
+    return list(repos)
 
 
 def add_prefix_repo(repo: str):
@@ -102,10 +92,12 @@ def add_prefix_repo(repo: str):
         info(l10n("repo-adding", name=repo_name, conf=env.prefix().CONFIG))
 
     set_config_value("REPOS", " ".join(sorted(enabled_repos)))
+    # Re-set prefix so that env.prefix().REPOS is updated
+    env.set_prefix(env.PREFIX_NAME)
 
 
 def get_repo_name(value: str) -> str:
-    repos = get_repos_list(env.prefix().ARCH)
+    repos = list(get_remote_repos(env.prefix().ARCH).values())
     if value.isdigit():
         repo_name = repos[int(value)].name
     else:
@@ -123,7 +115,9 @@ def set_profile(index: int):
     if os.path.lexists(linkpath):
         os.unlink(linkpath)
     (path, _, _) = [
-        tup for value in get_profiles(env.prefix().ARCH).values() for tup in value
+        tup
+        for value in get_profiles(env.prefix().ARCH, env.prefix().REPOS).values()
+        for tup in value
     ][index]
     os.symlink(path, linkpath)
 
@@ -181,9 +175,7 @@ def add_repo_parser(subparsers, parents):
 
     def add_func(args):
         add_prefix_repo(args.repo)
-        repo = next(
-            repo for repo in get_repos_list(env.prefix().ARCH) if repo.name == args.repo
-        )
+        repo = get_remote_repos(env.prefix().ARCH)[args.repo]
         result = add_repo(repo)
         if result:
             sync([result])
