@@ -93,6 +93,87 @@ def deselect(pkgs: Iterable[str], *, no_confirm: bool = False):
             remove_set("selected-packages", mod)
 
 
+def _update_configuration(
+    keyword_changes: Iterable[KeywordDep],
+    license_changes: Iterable[LicenseDep],
+    use_changes: Iterable[UseDep],
+    *,
+    no_confirm: bool,
+):
+    if keyword_changes:
+        for keyword in keyword_changes:
+            if keyword.masked:
+                error(
+                    l10n(
+                        "package-masked-keyword",
+                        atom=keyword.atom.CPN,
+                        arch=env.prefix().ARCH,
+                    )
+                )
+                return
+
+        print(l10n("necessary-keyword-changes"))
+        for keyword in keyword_changes:
+            if keyword.keyword.startswith("*"):
+                c = red
+            else:
+                c = yellow
+            print("    {} {}".format(green(keyword.atom), c(keyword.keyword)))
+
+        if no_confirm or prompt_bool(l10n("apply-changes-qn")):
+            for keyword in keyword_changes:
+                add_keyword(keyword.atom, keyword.keyword)
+        else:
+            return
+
+    if license_changes:
+        # TODO: For EULA licenses, display the license and prompt the user to accept
+        print(l10n("necessary-license-changes"))
+        for license in license_changes:
+            print("    {} {}".format(green(license.atom), license.license))
+        return
+
+    if use_changes:
+        display_flags: Dict[str, FlagDesc] = {}
+        for use in use_changes:
+            flag = use.flag.lstrip("-")
+            desc = get_flag_desc(load_pkg_fq(use.atom), flag)
+            if isinstance(desc, LocalFlagDesc):
+                display_flags[desc.pkg.ATOM.use(flag)] = desc
+            else:
+                display_flags[flag] = desc or FlagDesc("<missing description>")
+
+        for key, value in display_flags.items():
+            print(l10n("use-flag-desc", desc=value, flag=bright(lgreen(key))))
+
+        print()
+        print(l10n("necessary-flag-changes"))
+        for use in use_changes:
+            if use.flag.startswith("-") and use.oldvalue == use.flag.lstrip("-"):
+                print(
+                    "    {} {} # {}".format(
+                        lblue(use.atom), red(use.flag), l10n("enabled-comment")
+                    )
+                )
+            elif not use.flag.startswith("-") and use.oldvalue == "-" + use.flag:
+                print(
+                    "    {} {} # {}".format(
+                        green(use.atom), red(use.flag), l10n("disabled-comment")
+                    )
+                )
+            else:
+                print("    {} {}".format(green(use.atom), red(use.flag)))
+        if no_confirm or prompt_bool(l10n("apply-changes-qn")):
+            for use in use_changes:
+                add_use(
+                    use.flag.lstrip("-"),
+                    Atom(use.atom.CPF),
+                    use.flag.startswith("-"),
+                )
+        else:
+            return
+
+
 def configure(
     atoms: Iterable[str],
     *,
@@ -227,67 +308,9 @@ def configure(
             filter(lambda x: isinstance(x, LicenseDep), transactions.config)
         )
         use_changes = list(filter(lambda x: isinstance(x, UseDep), transactions.config))
-        if keyword_changes:
-            print(l10n("necessary-keyword-changes"))
-            for keyword in keyword_changes:
-                if keyword.keyword.startswith("*"):
-                    c = red
-                else:
-                    c = yellow
-                print("    {} {}".format(green(keyword.atom), c(keyword.keyword)))
-
-            if no_confirm or prompt_bool(l10n("apply-changes?")):
-                for keyword in keyword_changes:
-                    add_keyword(keyword.atom, keyword.keyword)
-            else:
-                return
-
-        if license_changes:
-            # TODO: For EULA licenses, display the license and prompt the user to accept
-            print(l10n("necessary-license-changes"))
-            for license in license_changes:
-                print("    {} {}".format(green(license.atom), license.license))
-            return
-
-        if use_changes:
-            display_flags: Dict[str, FlagDesc] = {}
-            for use in use_changes:
-                flag = use.flag.lstrip("-")
-                desc = get_flag_desc(load_pkg_fq(use.atom), flag)
-                if isinstance(desc, LocalFlagDesc):
-                    display_flags[desc.pkg.ATOM.use(flag)] = desc
-                else:
-                    display_flags[flag] = desc or FlagDesc("<missing description>")
-
-            for key, value in display_flags.items():
-                print(l10n("use-flag-desc", desc=value, flag=bright(lgreen(key))))
-
-            print()
-            print(l10n("necessary-flag-changes"))
-            for use in use_changes:
-                if use.flag.startswith("-") and use.oldvalue == use.flag.lstrip("-"):
-                    print(
-                        "    {} {} # {}".format(
-                            lblue(use.atom), red(use.flag), l10n("enabled-comment")
-                        )
-                    )
-                elif not use.flag.startswith("-") and use.oldvalue == "-" + use.flag:
-                    print(
-                        "    {} {} # {}".format(
-                            green(use.atom), red(use.flag), l10n("disabled-comment")
-                        )
-                    )
-                else:
-                    print("    {} {}".format(green(use.atom), red(use.flag)))
-            if no_confirm or prompt_bool(l10n("apply-changes-qn")):
-                for use in use_changes:
-                    add_use(
-                        use.flag.lstrip("-"),
-                        Atom(use.atom.CPF),
-                        use.flag.startswith("-"),
-                    )
-            else:
-                return
+        _update_configuration(
+            keyword_changes, license_changes, use_changes, no_confirm=no_confirm
+        )
 
     # Create a temporary VDB so that common packages needed for pkg_nofetch and pkg_pretend
     # but that haven't yet been installed can be found by the loader
