@@ -2,14 +2,16 @@
 # Distributed under the terms of the GNU General Public License v3
 
 import configparser
+import csv
 import getpass
 import os
 import re
 from functools import lru_cache
 from logging import info, warning
 from stat import S_IWRITE
-from typing import Mapping
+from typing import Mapping, NamedTuple, Optional
 
+from portmodlib.fs import is_parent
 from portmodlib.l10n import l10n
 
 from .globals import env
@@ -33,17 +35,32 @@ class PrefixExistsError(RuntimeError):
         return l10n("prefix-exists", prefix=self.prefix)
 
 
+class Prefix(NamedTuple):
+    arch: str
+    path: Optional[str]
+
+
 @lru_cache()
-def get_prefixes() -> Mapping[str, str]:
+def get_prefixes() -> Mapping[str, Prefix]:
     """Returns a mapping of prefixes to their architectures"""
     prefixes = {}
     if os.path.exists(env.PREFIX_FILE):
-        with open(env.PREFIX_FILE, "r") as file:
-            for line in file.readlines():
-                line = re.sub("#.*", "", line)
-                if line:
-                    prefix, arch = line.split()
-                    prefixes[prefix] = arch
+        with open(env.PREFIX_FILE, "r", newline="") as file:
+            # Ignore empty lines and comments
+            lines = filter(
+                bool, map(lambda x: re.sub("#.*", "", x).strip(), file.readlines())
+            )
+            csvdata = csv.reader(
+                lines, delimiter=" ", dialect="unix", quoting=csv.QUOTE_MINIMAL
+            )
+            for row in csvdata:
+                prefix = row[0]
+                arch = row[1]
+                directory = None
+                if len(row) > 2:
+                    directory = row[2]
+
+                prefixes[prefix] = Prefix(arch, directory)
 
     return prefixes
 
@@ -62,7 +79,7 @@ def remove_prefix(prefix: str):
         lines = file.readlines()
         origlines = list(lines)
         for index, line in enumerate(lines):
-            file_prefix, _ = line.split()
+            file_prefix, _, _ = line.partition(" ")
             if prefix == file_prefix:
                 del lines[index]
 
@@ -76,8 +93,19 @@ def remove_prefix(prefix: str):
     get_prefixes.cache_clear()
 
 
-def add_prefix(prefix: str, arch: str):
-    """Adds a new prefix"""
+def add_prefix(prefix: str, arch: str, directory: Optional[str] = None):
+    """
+    Adds a new prefix
+
+    args:
+        prefix: Name of the prefix
+        arch: Architecture of the prefix
+        directory: Optional initial directory to store the prefix inside
+                   If not included it will be stored with other portmod files
+                   (~/.local/share/portmod on Linux)
+                   Any files which are already in the directory will be backed up
+                   if overwritten, and restored when the prefix is destroyed
+    """
 
     invalid_prefixes = {"news", "sync", "mirror"}
 
@@ -94,6 +122,26 @@ def add_prefix(prefix: str, arch: str):
     if arch not in arch_options:
         warning(l10n("unknown-arch", arch=arch))
 
+    if directory:
+        if not os.access(directory, os.W_OK):
+            raise PermissionError(l10n("directory-not-writable", path=directory))
+
+        existing_prefixes = get_prefixes()
+        for name, existing_prefix in existing_prefixes.items():
+            # directory cannot overlap with other prefixes
+            existing_path = existing_prefix.path or os.path.join(env.DATA_DIR, name)
+            if is_parent(directory, existing_path) or is_parent(
+                existing_path, directory
+            ):
+                raise FileExistsError(
+                    l10n(
+                        "prefix-overlap",
+                        newpath=directory,
+                        oldpath=existing_path,
+                        prefix=name,
+                    )
+                )
+
     # Add new prefix to the prefix file
     if os.path.exists(env.PREFIX_FILE):
         stat = os.stat(env.PREFIX_FILE)
@@ -101,8 +149,14 @@ def add_prefix(prefix: str, arch: str):
 
     os.makedirs(os.path.dirname(env.PREFIX_FILE), exist_ok=True)
 
-    with open(env.PREFIX_FILE, "a") as file:
-        print(prefix, arch, file=file)
+    with open(env.PREFIX_FILE, "a", newline="") as file:
+        writer = csv.writer(
+            file, delimiter=" ", dialect="unix", quoting=csv.QUOTE_MINIMAL
+        )
+        if directory is None:
+            writer.writerow([prefix, arch])
+        else:
+            writer.writerow([prefix, arch, os.path.abspath(directory)])
 
     stat = os.stat(env.PREFIX_FILE)
     os.chmod(env.PREFIX_FILE, stat.st_mode - S_IWRITE, follow_symlinks=True)
@@ -111,12 +165,15 @@ def add_prefix(prefix: str, arch: str):
 
     env.set_prefix(prefix)
 
-    # Ensure that INSTALLED_DB exists
-    if not os.path.exists(env.prefix().INSTALLED_DB):
+    # If the database already existed, it will not be recreated
+    if os.path.exists(env.prefix().INSTALLED_DB):
+        print(l10n("database-exists", path=env.prefix().INSTALLED_DB))
+    else:
         import git
 
         # Initialize as git repo
         os.makedirs(env.prefix().INSTALLED_DB)
+
         gitrepo = git.Repo.init(env.prefix().INSTALLED_DB)
         # This repository is for local purposes only.
         # We don't want to worry about prompts for the user's gpg key password
