@@ -45,7 +45,7 @@ from portmodlib.pybuild import (
     get_installed_env,
 )
 from portmodlib.source import Source, get_archive_basename
-from portmodlib.usestr import check_required_use, use_reduce
+from portmodlib.usestr import UseParserError, check_required_use, use_reduce
 
 
 class Pybuild(BasePybuild):
@@ -236,25 +236,37 @@ class Pybuild(BasePybuild):
                 "PROPERTIES must be a string containing a space separated list"
             )
 
-        IUSE_STRIP = set([use.lstrip("+") for use in self.IUSE])
+        IUSE_STRIP = {use.lstrip("+") for use in self.IUSE}
         errors = []
 
-        try:
-            rdeps = use_reduce(self.RDEPEND, token_class=Atom, matchall=True, flat=True)
-        except Exception as e:
-            errors.append(f"Failed to parse RDEPEND: {e}")
+        def check_use_reduce(attr: str, *, is_src_uri: bool = False, token_class=str):
+            try:
+                return use_reduce(
+                    getattr(self, attr),
+                    token_class=token_class,
+                    matchall=True,
+                    flat=True,
+                    is_valid_flag=self.valid_use,
+                    is_src_uri=is_src_uri,
+                )
+            except UseParserError as error:
+                errors.append(f"Failed to parse {attr}: {error}")
 
-        try:
-            deps = use_reduce(self.DEPEND, token_class=Atom, matchall=True, flat=True)
-        except Exception as e:
-            errors.append(f"Failed to parse DEPEND: {e}")
+        rdeps = check_use_reduce("RDEPEND", token_class=Atom)
+        deps = check_use_reduce("DEPEND", token_class=Atom)
+        overrides = check_use_reduce("DATA_OVERRIDES", token_class=Atom)
+        check_use_reduce("HOMEPAGE")
+        check_use_reduce("SRC_URI", is_src_uri=True)
+        check_use_reduce("PATCHES")
+        licenses = check_use_reduce("LICENSE")
 
-        try:
-            overrides = use_reduce(
-                self.DATA_OVERRIDES, token_class=Atom, matchall=True, flat=True
-            )
-        except Exception as e:
-            errors.append(f"Failed to parse DATA_OVERRIDES: {e}")
+        for license in licenses:
+            if license != "||" and not license_exists(self.REPO_PATH, license):
+                errors.append(
+                    f"LICENSE {license} does not exist! Please make sure that it named "
+                    "correctly, or if it is a new License that it is added to "
+                    "the licenses directory of the repository"
+                )
 
         for atom in rdeps + deps:
             if isinstance(atom, Atom) and not pkg_exists(atom, repo_name=self.REPO):
@@ -264,48 +276,45 @@ class Pybuild(BasePybuild):
             if isinstance(atom, Atom) and not pkg_exists(atom, repo_name=self.REPO):
                 errors.append(f"Data Override {atom} could not be found!")
 
-        try:
-            use_reduce(self.PATCHES, matchall=True)
-        except Exception as e:
-            errors.append(f"Failed to parse PATCHES: {e}")
-
         for install in self.INSTALL_DIRS:
             if not isinstance(install, InstallDir):
-                errors.append(
-                    'InstallDir "{}" must have type InstallDir'.format(install.PATH)
-                )
+                errors.append(f'InstallDir "{install}" must have type InstallDir')
                 continue
             for file in install.get_files():
                 if not isinstance(file, File):
-                    errors.append('File "{}" must have type File'.format(file))
+                    errors.append(f'File "{file}" must have type File')
                     continue
 
                 try:
                     check_required_use(file.REQUIRED_USE, set(), self.valid_use)
-                except Exception as e:
-                    errors.append("Error processing file {}: {}".format(file.NAME, e))
+                except UseParserError as error:
+                    errors.append(f"Error processing file {file.NAME}: {error}")
 
             try:
                 check_required_use(install.REQUIRED_USE, set(), self.valid_use)
-            except Exception as e:
-                errors.append("Error processing dir {}: {}".format(install.PATH, e))
+            except UseParserError as error:
+                errors.append(f"Error processing dir {install.PATH}: {error}")
 
-            if install.WHITELIST is not None and type(install.WHITELIST) is not list:
-                errors.append("WHITELIST {} must be a list".format(install.WHITELIST))
+            if install.WHITELIST is not None and not isinstance(
+                install.WHITELIST, list
+            ):
+                errors.append(f"WHITELIST {install.WHITELIST} must be a list")
             elif install.WHITELIST is not None:
                 for string in install.WHITELIST:
-                    if type(string) is not str:
+                    if not isinstance(string, str):
                         errors.append(
-                            "{} in InstallDir WHITELIST is not a string".format(string)
+                            f'"{string}" in InstallDir WHITELIST is not a string'
                         )
 
-            if install.BLACKLIST is not None and type(install.BLACKLIST) is not list:
-                errors.append("BLACKLIST {} must be a list".format(install.BLACKLIST))
+            if install.BLACKLIST is not None and not isinstance(
+                install.BLACKLIST, list
+            ):
+                errors.append(f"BLACKLIST {install.BLACKLIST} must be a list")
             elif install.BLACKLIST is not None:
                 for string in install.BLACKLIST:
-                    if type(string) is not str:
+                    if not isinstance(string, str):
                         errors.append(
-                            "{} in InstallDir BLACKLIST is not a string".format(string)
+                            f'"{string}" in InstallDir BLACKLIST is not a string'
                         )
 
             if install.WHITELIST is not None and install.BLACKLIST is not None:
@@ -348,17 +357,6 @@ class Pybuild(BasePybuild):
         if not isinstance(self.HOMEPAGE, str) or "FILLME" in self.HOMEPAGE:
             errors.append("Please fill in the HOMEPAGE field")
 
-        for license in use_reduce(self.LICENSE, flat=True, matchall=True):
-            if license != "||" and not license_exists(self.REPO_PATH, license):
-                errors.append(
-                    "LICENSE {} does not exit! Please make sure that it named "
-                    "correctly, or if it is a new License that it is added to "
-                    "the licenses directory of the repository".format(license)
-                )
-
-        if not isinstance(self.PATCHES, str):
-            errors.append("PATCHES must be a string")
-
         all_sources = self._get_sources(matchall=True)
 
         for install in self.INSTALL_DIRS:
