@@ -37,7 +37,7 @@ from .loader import load_all, load_all_installed, load_installed_pkg, load_pkg
 from .pybuild import Pybuild
 from .repo import get_repo
 from .repo.metadata import get_global_use, get_package_metadata, get_use_expand_values
-from .util import get_newest
+from .util import get_newest, sort_by_version
 
 
 def get_maintainer_string(maintainers: Union[List[Any], Any]) -> str:
@@ -263,7 +263,7 @@ def display_search_results(
     count = 0
     for group in package_groups:
         count += 1
-        sortedmods = sorted(group, key=lambda mod: mod.PV)
+        sortedmods = sort_by_version(group)
         newest = get_newest(group)
         installed = load_installed_pkg(Atom(newest.CPN))
         download = get_total_download_size([newest])
