@@ -4,15 +4,15 @@
 import os
 import shutil
 from logging import error, info, warning
-from typing import Iterable
+from typing import Iterable, cast
 
 from packaging import version
 
 from portmod.globals import env, get_version
 from portmod.news import update_news
-from portmod.repo import Repo
-from portmod.repo.metadata import get_masters
-from portmod.repos import get_local_repos
+from portmod.repo import Repo, get_repo, has_repo
+from portmod.repo.metadata import get_master_names
+from portmod.repos import add_repo, get_local_repos, get_remote_repos
 from portmodlib.l10n import l10n
 
 
@@ -90,7 +90,14 @@ def sync(repos: Iterable[Repo]):
                 )
             )
 
-        for master_repo in get_masters(repo.location):
+        remote_repos = get_remote_repos()
+        for master in get_master_names(repo.location):
+            if has_repo(master):
+                master_repo = get_repo(master)
+            else:
+                # As the repository did not previously exist, add_repo will not
+                # return None
+                master_repo = cast(Repo, add_repo(remote_repos[master]))
             if master_repo not in to_sync:
                 to_sync.append(master_repo)
 
