@@ -6,7 +6,8 @@ Various utility functions
 """
 
 from collections import namedtuple
-from typing import Any, Iterable, Optional, Tuple
+from functools import cmp_to_key
+from typing import Any, Iterable, List, Optional, Tuple
 
 from portmod.config.license import has_eula, is_license_accepted
 from portmod.repo.keywords import accepts, accepts_testing, get_keywords
@@ -112,3 +113,19 @@ def get_newest(packages: Iterable[Pybuild]) -> Pybuild:
     raise Exception(
         f"Internal Error: get_max_version returned incorrect result {max_ver}"
     )
+
+
+def sort_by_version(packages: Iterable[Pybuild]) -> List[Pybuild]:
+    """
+    Sorts the given packages in order of version
+
+    Uses version_gt for version comparison
+    """
+
+    def version_cmp(x, y):
+        if version_gt(x.PVR, y.PVR):
+            return 1
+        else:
+            return -1
+
+    return sorted(packages, key=cmp_to_key(version_cmp))
