@@ -161,6 +161,9 @@ def ci_exists(path: str) -> Optional[str]:
     partial_path = "/"
     for component in os.path.normpath(os.path.abspath(path)).split(os.sep)[1:]:
         found = False
+        # The entry that exists is not a directory, so it cannot have any contents
+        if not os.path.isdir(partial_path):
+            return None
         for entryname in os.listdir(partial_path):
             if entryname.lower() == component.lower():
                 partial_path = os.path.join(partial_path, entryname)
@@ -202,6 +205,8 @@ def is_parent(path: str, prefix: str) -> bool:
     returns:
         True if and only if prefix is a parent directory of path
     """
+    path = os.path.normpath(os.path.abspath(path))
+    prefix = os.path.normpath(os.path.abspath(prefix))
     return (
         os.path.splitdrive(path)[0] == os.path.splitdrive(prefix)[0]
         and os.path.commonpath([path, prefix]) == prefix
