@@ -1,4 +1,4 @@
-# Copyright 2019-2020 Portmod Authors
+# Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
 import os
@@ -35,3 +35,7 @@ def config_protect_dir() -> str:
 
 def tmp_vdb() -> str:
     return os.environ["PORTMOD_TMP_VDB"]
+
+
+def local_mods() -> str:
+    return os.environ["PORTMOD_LOCAL_MODS"]
