@@ -8,7 +8,7 @@ from pathlib import Path
 from typing import Any, Generator, Iterable, List, Optional, Set, Tuple, Union
 
 from .atom import Atom, FQAtom, QualifiedAtom
-from .globals import root
+from .globals import local_mods, root
 from .source import Source
 from .usestr import check_required_use, use_reduce
 
@@ -332,9 +332,13 @@ class BasePybuild:
 
     def get_dir_path(self, install_dir: InstallDir) -> str:
         """Returns the installed path of the given InstallDir"""
-        path = os.path.normpath(
-            os.path.join(root(), self._get_install_dir_dest(), install_dir.PATCHDIR)
-        )
+        # Local dirs should be relative to LOCAL_MODS
+        if "local" in self.PROPERTIES:
+            path = os.path.normpath(os.path.join(local_mods(), self.PN))
+        else:
+            path = os.path.normpath(
+                os.path.join(root(), self._get_install_dir_dest(), install_dir.PATCHDIR)
+            )
         if os.path.islink(path):
             return os.readlink(path)
         else:
