@@ -31,17 +31,22 @@ def find_file(name: str) -> str:
         The absolute path of the file
     """
     # FIXME: This should respect the CASE_INSENSITIVE_FILES setting
-    for directory in reversed(get_vfs_dirs()):
-        path = ci_exists(os.path.join(directory, name))
+    if os.environ.get("VFS"):
+        for directory in reversed(get_vfs_dirs()):
+            path = ci_exists(os.path.join(directory, name))
+            if path:
+                return path
+
+        for archive in reversed(get_vfs_archives()):
+            contents = list_archive(archive)
+            for file in contents:
+                if os.path.normpath(file).lower() == os.path.normpath(name).lower():
+                    return extract_archive_file_to_tmp(archive, file)
+    else:
+        path = ci_exists(os.path.join(root(), name))
         if path:
             return path
 
-    for archive in reversed(get_vfs_archives()):
-        contents = list_archive(archive)
-        for file in contents:
-            if os.path.normpath(file).lower() == os.path.normpath(name).lower():
-                return extract_archive_file_to_tmp(archive, file)
-
     raise FileNotFoundError(name)
 
 
@@ -61,21 +66,28 @@ def list_dir(name: str) -> List[str]:
 
     # FIXME: This should respect the CASE_INSENSITIVE_FILES setting
 
-    for directory in reversed(get_vfs_dirs()):
-        path = ci_exists(os.path.join(directory, normalized))
+    if os.environ.get("VFS"):
+        for directory in reversed(get_vfs_dirs()):
+            path = ci_exists(os.path.join(directory, normalized))
+            if path:
+                for file in os.listdir(path):
+                    if file.lower() not in files:
+                        files[file.lower()] = file
+
+        for archive in reversed(get_vfs_archives()):
+            contents = list_archive(archive)
+            for file in contents:
+                if is_parent(os.path.normpath(file).lower(), normalized):
+                    suffix = os.path.relpath(os.path.normpath(file).lower(), normalized)
+                    component, _, _ = suffix.partition(os.sep)
+                    files[component] = component
+    else:
+        path = ci_exists(os.path.join(root(), normalized))
         if path:
             for file in os.listdir(path):
                 if file.lower() not in files:
                     files[file.lower()] = file
 
-    for archive in reversed(get_vfs_archives()):
-        contents = list_archive(archive)
-        for file in contents:
-            if is_parent(os.path.normpath(file).lower(), normalized):
-                suffix = os.path.relpath(os.path.normpath(file).lower(), normalized)
-                component, _, _ = suffix.partition(os.sep)
-                files[component] = component
-
     return sorted(files.values())
 
 
