@@ -12,7 +12,10 @@ from portmodlib.fs import patch_dir  # noqa  # pylint: disable=unused-import
 from portmodlib.globals import download_dir as _download_dir
 from portmodlib.masters import get_masters  # noqa  # pylint: disable=unused-import
 from portmodlib.pybuild import File, InstallDir  # noqa  # pylint: disable=unused-import
-from portmodlib.usestr import use_reduce  # noqa  # pylint: disable=unused-import
+from portmodlib.usestr import (  # noqa  # pylint: disable=unused-import
+    check_required_use,
+    use_reduce,
+)
 from portmodlib.vfs import find_file, list_dir  # noqa  # pylint: disable=unused-import
 
 from .pybuild import Pybuild1, apply_patch  # noqa  # pylint: disable=unused-import
