@@ -33,7 +33,7 @@ def test_init_prefix():
     sys.argv = ["portmod", "init", "test2", "test", "--no-confirm"]
     main()
 
-    assert get_prefixes()["test2"] == "test"
+    assert get_prefixes()["test2"].arch == "test"
     sys.argv = ["portmod", "test2", "destroy", "--no-confirm"]
     main()
     assert "test2" not in get_prefixes()
